==> sxlog-1.0.6.zip: ext/app/main.php <==
<?php
// 应用中心
if($page == 'admin' && $adminPage == 'app'){

	//登录限制
	if(!LOGIN) jump('admin/login');

	//模板编译
	$appTpl = new Tpl([
		'path' => '/ext/',
		'name' => 'app',
		'compile' => $conf['compile'],
	]);

	//页面路由
	$appPage = get(2,'str','tpl');
	$appType = get(3,'str','index');

	//用户key
	$keyPath = EXT.'app/key.php';
	if(!is_file($keyPath)) save($keyPath,['host'=>'','key'=>'']);
	$userKey = include $keyPath;

	//验证host
	if($_SERVER['SERVER_NAME'] !== $userKey['host']){
		$userKey = ['host'=>$_SERVER['SERVER_NAME'],'key'=>''];
		save($keyPath,$userKey);
	}

	/**
	 * 获取官方应用中心数据
	 * @param  string $url
	 * @param  bool|array|string $params
	 * @return string
	 */
	function getApi($url,$params=[]){
		global $userKey;
		$tpl = getTpl();
		$ext = getExt();
		$res = curl('https://xueluo.cn/api/'.$url,array_merge($userKey,[
			'system'=>[
				'version'=>V,
			],
			'url'=>URL,
			'tpl'=>$tpl['list'],
			'ext'=>$ext['list']
		],$params));
		$arr = type($res,'array');
		if(type($arr) == 'array' && $arr['error'] === 4001){
			jump('admin/app/login');
		}
		return $res;
	}

	//登录
	if($appPage == 'login'){
		if($method == 'POST'){
			$form = post('form','int',1);
			$username = post('username','str');
			$password = post('password','str');
			$res = getApi('login',['username'=>$username,'password'=>$password,'form'=>$form]);
			$arr = type($res,'array');
			if($arr && !$arr['error']){
				$userKey['key'] = $arr['data'];
				save($keyPath,$userKey);
				ajax(0,'登录成功');
			}
			exit($res);
		}
		$html = getApi('login');
		include $appTpl->view('app');
	}
	//退出
	elseif($appPage == 'logout'){
		$userKey['key'] = '';
		save($keyPath,$userKey);
		jump('admin/app/user');
	}
	//主题列表
	if($appPage == 'tpl'){
		$pageNum = get(3,'int',1);
		$pageSize = 30;
		$html = getApi('tpl',['page'=>$pageNum,'size'=>$pageSize]);
		include $appTpl->view('app');
	}
	//扩展列表
	elseif($appPage == 'ext'){
		$pageNum = get(3,'int',1);
		$pageSize = 30;
		$html = getApi('ext',['page'=>$pageNum,'size'=>$pageSize]);
		include $appTpl->view('app');
	}
	//应用详情
	elseif($appPage == 'view'){
		$type = get(3,'string');
		$id = get(4,'string');
		$html = getApi('view',['type'=>$type,'id'=>$id]);
		include $appTpl->view('app');
	}
	//应用评论
	elseif($appPage == 'comment'){
		$type = post('type','string');
		$id = post('id','string');
		$content = post('content','string');
		getApi('getView',['type'=>$type,'id'=>$id,'content'=>$content]);
		jump('admin/app/view/'.$type.'/'.$id);
	}
	//用户中心
	elseif($appPage == 'user'){
		$param = [];
		//账号设置
		if($appType == 'settingUpdate'){
			if($method == 'POST'){
				$param['password'] = post('password','str','');
				$param['question'] = post('question','str','');
				$param['answer'] = post('answer','str','');
				$param['contact'] = post('contact','str','');
				$param['mail'] = post('mail','str','');
				$param['home'] = post('home','str','');
				$param['content'] = post('content','str','');
				$res = getApi('user/'.$appType,$param);
				$arr = type($res,'array');
				if($arr && $arr['error']){
					prompt($arr['data']);
				}else{
					jump('admin/app/user');
				}
			}
		}
		$param['tab'] = get(3,'string','tpl');
		$html = getApi('user/'.$appType,$param);
		include $appTpl->view('app');
	}
	//应用编辑
	elseif($appPage == 'editor'){
		$type = get(3,'str');
		$id = get(4,'str');
		$html = getApi('editor',['type'=>$type,'id'=>$id]);
		include $appTpl->view('app');
	}
	//系统
	elseif($appPage == 'system'){
		$html = getApi('system');
		include $appTpl->view('app');
	}
	//安装
	elseif($appPage == 'install'){
		$id = get(4,'str');
		if($appType == 'tpl'){
			$res = getApi('download/tpl/'.$id);
			$arr = type($res,'array');
			if(type($arr) == 'array' && $arr['error']){
				ajax('1',$arr['data']);
			}
			unsx($res);
			$tpl->compile();
			ajax('0','安装成功');
		}
		elseif($appType == 'ext'){
			$res = getApi('download/ext/'.$id);
			$arr = type($res,'array');
			if(type($arr) == 'array' && $arr['error']){
				ajax(1,'安装失败');
			}
			unsx($res);
			ajax('0','安装成功');
		}
	}
	exit;
}
?>

==> sxlog-1.0.8.zip: ext/app/main.php <==
<?php
// 应用中心
if($page == 'admin' && $adminPage == 'app'){

	//登录限制
	if(!LOGIN) jump('admin/login');

	//模板编译
	$appTpl = new Tpl([
		'path' => '/ext/',
		'name' => 'app',
		'compile' => $conf['compile'],
	]);

	//页面路由
	$appPage = get(2,'str','tpl');
	$appType = get(3,'str','index');

	//用户key
	$keyPath = EXT.'app/key.php';
	if(!is_file($keyPath)) save($keyPath,['host'=>'','key'=>'']);
	$userKey = include $keyPath;

	//验证host
	if($_SERVER['SERVER_NAME'] !== $userKey['host']){
		$userKey = ['host'=>$_SERVER['SERVER_NAME'],'key'=>''];
		save($keyPath,$userKey);
	}

	/**
	 * 获取官方应用中心数据
	 * @param  string $url
	 * @param  bool|array|string $params
	 * @return string
	 */
	function getApi($url,$params=[]){
		global $userKey;
		$tpl = getTpl();
		$ext = getExt();
		$res = curl('https://xueluo.cn/api/'.$url,array_merge($userKey,[
			'system'=>[
				'version'=>V,
				'dbVersion'=>CONF['db']['version']
			],
			'url'=>URL,
			'tpl'=>$tpl['list'],
			'ext'=>$ext['list']
		],$params));
		$arr = type($res,'array');
		if(type($arr) == 'array' && $arr['error']){
			if($arr['error'] === 4001){
				jump('admin/app/login');
			}
			exit($res);
		}
		return $res;
	}

	//登录
	if($appPage == 'login'){
		if($method == 'POST'){
			$form = post('form','int',1);
			$username = post('username','str');
			$password = post('password','str');
			$res = getApi('login',['username'=>$username,'password'=>$password,'form'=>$form]);
			$arr = type($res,'array');
			if($arr && !$arr['error']){
				$userKey['key'] = $arr['data'];
				save($keyPath,$userKey);
				ajax(0,'登录成功');
			}
			exit($res);
		}
		$html = getApi('login');
		include $appTpl->view('app');
	}
	//退出
	elseif($appPage == 'logout'){
		$userKey['key'] = '';
		save($keyPath,$userKey);
		jump('admin/app/user');
	}
	//主题列表
	if($appPage == 'tpl'){
		$pageNum = get(3,'int',1);
		$pageSize = 30;
		$html = getApi('tpl',['page'=>$pageNum,'size'=>$pageSize]);
		include $appTpl->view('app');
	}
	//扩展列表
	elseif($appPage == 'ext'){
		$pageNum = get(3,'int',1);
		$pageSize = 30;
		$html = getApi('ext',['page'=>$pageNum,'size'=>$pageSize]);
		include $appTpl->view('app');
	}
	//应用详情
	elseif($appPage == 'view'){
		$type = get(3,'string');
		$id = get(4,'string');
		$html = getApi('view',['type'=>$type,'id'=>$id]);
		include $appTpl->view('app');
	}
	//应用评论
	elseif($appPage == 'comment'){
		$type = post('type','string');
		$id = post('id','string');
		$pid = post('pid','int',0);
		$content = post('content','string');
		$res = getApi('comment',['type'=>$type,'id'=>$id,'pid'=>$pid,'content'=>$content]);
		exit($res);
	}
	//应用评论删除
	elseif($appPage == 'deleteComment'){
		$type = post('type','string');
		$name = post('name','string');
		$id = post('id','int');
		$res = getApi('deleteComment',['type'=>$type,'name'=>$name,'id'=>$id]);
		exit($res);
	}
	//用户中心
	elseif($appPage == 'user'){
		$param = [];
		//账号设置
		if($appType == 'settingUpdate'){
			if($method == 'POST'){
				$param['password'] = post('password','str','');
				$param['question'] = post('question','str','');
				$param['answer'] = post('answer','str','');
				$param['contact'] = post('contact','str','');
				$param['mail'] = post('mail','str','');
				$param['home'] = post('home','str','');
				$param['content'] = post('content','str','');
				$res = getApi('user/'.$appType,$param);
				exit($res);
			}
		}
		$param['tab'] = get(3,'string','tpl');
		if($param['tab'] == 'develop'){
			$param['develop'] = 1;
			$param['tab'] = get(4,'string','tpl');
		}
		$html = getApi('user/'.$appType,$param);
		include $appTpl->view('app');
	}
	//应用编辑
	elseif($appPage == 'editor'){
		$type = get(3,'str');
		$id = get(4,'str');
		if($method == 'POST'){
			$name = post('name','str');
			$version = post('version','str');
			$price = post('price','int',0);
			$home = post('home','str');
			$intro = post('intro','str');
			$content = post('content','str');
			$res = getApi('editorForm',[
				'form'=>1,
				'type'=>$type,
				'id'=>$id,
				'name'=>$name,
				'version'=>$version,
				'price'=>$price,
				'home'=>$home,
				'intro'=>$intro,
				'content'=>$content,
			]);
			exit($res);
		}
		$html = getApi('editor',['type'=>$type,'id'=>$id]);
		include $appTpl->view('app');
	}
	//应用上架 下架 删除
	elseif($appPage == 'put' || $appPage == 'pull' || $appPage == 'del'){
		$type = get(3,'str');
		$id = get(4,'str');
		$res = getApi($appPage,['type'=>$type,'id'=>$id]);
		exit($res);
	}
	//系统
	elseif($appPage == 'system'){
		$html = getApi('system');
		include $appTpl->view('app');
	}
	//安装
	elseif($appPage == 'install'){
		$id = get(4,'str');
		if($appType == 'tpl'){
			$res = getApi('download/tpl/'.$id);
			$arr = type($res,'array');
			if(type($arr) == 'array' && $arr['error']){
				ajax('1',$arr['data']);
			}
			unsx($res);
			$tpl->compile();
			ajax('0','安装成功');
		}
		elseif($appType == 'ext'){
			$res = getApi('download/ext/'.$id);
			$arr = type($res,'array');
			if(type($arr) == 'array' && $arr['error']){
				ajax(1,'安装失败');
			}
			unsx($res);
			ajax('0','安装成功');
		}
	}
	exit;
}
?>
